##  Applying Labels
To improve representation and understanding, you can add labels to these arrows, which represent the interface fact sheets.
**Note**
By default, labels are shortened to 30 characters to improve readability. If a label exceeds 30 characters, hover over it to view the full text.
To apply a label, follow these steps:
  1. Click on Labels from the Toolbar.
  2. From the drop-down menu, select Interfaces.
  3. Choose the values/fields to be displayed.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27494bf67a441014af26933a61c97d53_LowRes.gif)
You can select and display multiple labels. All string fields and external IDs are available as labels. Labels can also be applied when interface fact sheets are represented as shapes, such as during drill-down.
If interface names are long or multiple labels are displayed, you can change the diagram layout to add necessary spacing. Select one of the following options in the layout dropdown:
  * Horizontal Label Flow: Expands diagram horizontally to accommodate labels.
  * Vertical Label Flow: Expands diagram vertically to accommodate labels.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio607eff6f96aa4363b1fbfc972b4b29de_LowRes.gif)
